/// <reference types="node" />
import querystring = require('querystring');
export declare const version = "v1.6.4";
export interface Config {
    varsnap: boolean;
    env: string;
    producerToken?: string;
    consumerToken?: string;
    logger?: Logger;
}
declare type ConfigKeys = keyof Config;
declare type rawJSONObject = ConsumeSnapResponse | ProduceTrialResponse | TrialGroupResponse | querystring.ParsedUrlQueryInput;
export interface Logger {
    debug(s: string): void;
    log(s: string): void;
    error(s: string): void;
}
export declare class Util {
    static getConfig(config: Config, configKey: ConfigKeys): string;
    static setConfig(config: Config, configKey: ConfigKeys, configValue: string | boolean | Logger | undefined): Config;
    static getSignature(targetFunc: TargetFunction, funcName: string): string;
    static ajax(url: string, requestData: rawJSONObject): Promise<rawJSONObject>;
    static debug(config: Config, data: string): void;
    static log(config: Config, data: string): void;
    static error(config: Config, data: string): void;
    static resetProducers(): void;
    static resetConsumers(): void;
    static getProducers(): Producer[];
    static getConsumers(): Consumer[];
    static limitString(x: TargetFunctionInput[] | TargetFunctionOutput): string;
}
export declare class Producer {
    targetFunc: TargetFunction;
    signature: string;
    config: Config;
    constructor(targetFunc: TargetFunction, signature: string, config: Config);
    isEnabled(): boolean;
    static serialize(data: TargetFunctionInput[] | TargetFunctionOutput): string;
    static serialize_formatted(data: TargetFunctionInput[] | TargetFunctionOutput): string;
    produce(args: TargetFunctionInput[], output: TargetFunctionOutput): Promise<boolean>;
}
interface ConsumeSnapResponse {
    status: string;
    results: Snap[];
}
interface Snap {
    id: string;
    inputs: string;
    prod_outputs: string;
}
interface ProduceTrialResponse {
    status: string;
    trial_url: string;
}
export declare class Consumer {
    targetFunc: TargetFunction;
    signature: string;
    config: Config;
    constructor(targetFunc: TargetFunction, signature: string, config: Config);
    isEnabled(): boolean;
    static deserialize(data: string): TargetFunctionInput[] | TargetFunctionOutput | undefined;
    consume(trialGroupID: string): Promise<boolean>;
    reportCentral(trialGroupID: string, snap: Snap, prodOutputs: TargetFunctionOutput, localOutputs: TargetFunctionOutput, matches: boolean): Promise<string | boolean>;
    reportLog(snapID: string, inputs: TargetFunctionInput[], prodOutputs: TargetFunctionOutput, localOutputs: TargetFunctionOutput, matches: boolean, trialURL: string | boolean): void;
}
export declare type TargetFunctionInput = any;
export declare type TargetFunctionOutput = any;
export interface TargetFunction {
    (...args: TargetFunctionInput[]): TargetFunctionOutput;
}
export interface WrappedFunction {
    (...args: TargetFunctionInput[]): TargetFunctionOutput;
    producer: Producer;
    consumer: Consumer;
    signature: string;
}
export declare function varsnap(func: TargetFunction, funcName?: string): TargetFunction | WrappedFunction;
export declare namespace varsnap {
    var _config: Config;
    var updateConfig: (newConfig: Config) => void;
    var reset: () => void;
    var version: string;
    var runTests: typeof import("./core").runTests;
}
interface TrialGroupResponse {
    status: string;
    project_id: string;
    trial_group_id: string;
}
export declare function runTests(): Promise<boolean>;
export {};
